@@ -1,7 +1,7 @@
 var ustring_8h =
 [
     [ "UString", "classSteinberg_1_1UString.html", "classSteinberg_1_1UString" ],
-    [ "UStringBuffer", "classSteinberg_1_1UStringBuffer.html", "classSteinberg_1_1UStringBuffer" ],
+    [ "UStringBuffer< maxSize >", "classSteinberg_1_1UStringBuffer.html", "classSteinberg_1_1UStringBuffer" ],
     [ "USTRING", "ustring_8h.html#ac5f8dfe73b55c4ec26f12c071d67bffb", null ],
     [ "USTRINGSIZE", "ustring_8h.html#abbca26150973e505a5e42d3854b49750", null ],
     [ "UString128", "ustring_8h.html#aa92186fdeda699e7a0cc7ac6c45d07e5", null ],
