@@ -1,7 +1,7 @@
 var ivstprefetchablesupport_8h =
 [
     [ "IPrefetchableSupport", "classSteinberg_1_1Vst_1_1IPrefetchableSupport.html", "classSteinberg_1_1Vst_1_1IPrefetchableSupport" ],
-    [ "PrefetchableSupport", "ivstprefetchablesupport_8h.html#ga8cd3dd5ea75e76ace81fd1a696544378", null ],
+    [ "PrefetchableSupport", "ivstprefetchablesupport_8h.html#a8cd3dd5ea75e76ace81fd1a696544378", null ],
     [ "ePrefetchableSupport", "ivstprefetchablesupport_8h.html#a18aa40e583fe3a75b569e7129e0d89b5", [
       [ "kIsNeverPrefetchable", "ivstprefetchablesupport_8h.html#a18aa40e583fe3a75b569e7129e0d89b5a056d564a22f73e4649c99e1407a7585a", null ],
       [ "kIsYetPrefetchable", "ivstprefetchablesupport_8h.html#a18aa40e583fe3a75b569e7129e0d89b5aa43449cf5a0e596fa81b4a8498404f3f", null ],
