@@ -1,7 +1,7 @@
 var dataexchange_8h =
 [
     [ "DataExchangeHandler", "classSteinberg_1_1Vst_1_1DataExchangeHandler.html", "classSteinberg_1_1Vst_1_1DataExchangeHandler" ],
-    [ "Config", "structSteinberg_1_1Vst_1_1DataExchangeHandler_1_1Config.html", "structSteinberg_1_1Vst_1_1DataExchangeHandler_1_1Config" ],
+    [ "DataExchangeHandler::Config", "structSteinberg_1_1Vst_1_1DataExchangeHandler_1_1Config.html", "structSteinberg_1_1Vst_1_1DataExchangeHandler_1_1Config" ],
     [ "DataExchangeReceiverHandler", "classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html", "classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler" ],
     [ "operator!=", "dataexchange_8h.html#ab1444bade1e2d33212f2fe2e8c760acf", null ],
     [ "operator==", "dataexchange_8h.html#a1df79da3fa9e3615e855efe07534b62b", null ]
