@@ -23,7 +23,7 @@ var group__vstClasses =
     ] ],
     [ "Bus", "classSteinberg_1_1Vst_1_1Bus.html", [
       [ "Bus", "classSteinberg_1_1Vst_1_1Bus.html#a3648ba31bae2ff74f94633ca0cdc132d", null ],
-      [ "isActive", "classSteinberg_1_1Vst_1_1Bus.html#a7e0a17a20c2f0dd2d3d1e6a62c327cf6", null ],
+      [ "isActive", "classSteinberg_1_1Vst_1_1Bus.html#a0ee9c7168f156968610adcdcaa3c40f6", null ],
       [ "setActive", "classSteinberg_1_1Vst_1_1Bus.html#aae14a6e1893dd077921ef60eda26335b", null ],
       [ "setName", "classSteinberg_1_1Vst_1_1Bus.html#af32f37d074468cc02690c5738ee81454", null ],
       [ "setBusType", "classSteinberg_1_1Vst_1_1Bus.html#ad29e2bc8c425947f942818092cbd7515", null ],
@@ -41,14 +41,14 @@ var group__vstClasses =
     ] ],
     [ "AudioBus", "classSteinberg_1_1Vst_1_1AudioBus.html", [
       [ "AudioBus", "classSteinberg_1_1Vst_1_1AudioBus.html#aa88e9bd8e9d969a00f0bd035a03c359f", null ],
-      [ "getArrangement", "classSteinberg_1_1Vst_1_1AudioBus.html#a45a06cc98257a31820ae72df7bb84314", null ],
+      [ "getArrangement", "classSteinberg_1_1Vst_1_1AudioBus.html#a7e8ae213aa720be5b524a1af068881a9", null ],
       [ "setArrangement", "classSteinberg_1_1Vst_1_1AudioBus.html#a8b76fd7d8c1dc97ad1a7ddcd9ee7f265", null ],
       [ "getInfo", "classSteinberg_1_1Vst_1_1AudioBus.html#a5570b4631f4b2d4660a1b53e65c3d876", null ]
     ] ],
     [ "BusList", "classSteinberg_1_1Vst_1_1BusList.html", [
       [ "BusList", "classSteinberg_1_1Vst_1_1BusList.html#a5ba12052fe11364762c6b63f2e075961", null ],
-      [ "getType", "classSteinberg_1_1Vst_1_1BusList.html#a7a913769aed1c96575f65637fcf7be43", null ],
-      [ "getDirection", "classSteinberg_1_1Vst_1_1BusList.html#a645194adff2311551059769c2bf92d24", null ],
+      [ "getType", "classSteinberg_1_1Vst_1_1BusList.html#a417296c9e5b33cfef9926eba3d3dd663", null ],
+      [ "getDirection", "classSteinberg_1_1Vst_1_1BusList.html#a20c9187487ae211f2cff4f9d51e94caa", null ],
       [ "OBJ_METHODS", "classSteinberg_1_1Vst_1_1BusList.html#afa61be27ee943dd7a9130d4915756974", null ],
       [ "type", "classSteinberg_1_1Vst_1_1BusList.html#a9efc310404a7d775d72cc8974e5e3b58", null ],
       [ "direction", "classSteinberg_1_1Vst_1_1BusList.html#abb6aef5950e795ec6507d07a5c8bd4fe", null ]
@@ -81,12 +81,12 @@ var group__vstClasses =
     [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html", [
       [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html#ab3b1f8979c4bbe983e42010925959fd3", null ],
       [ "~ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html#a992af1025ac7720ce29a87d926531e05", null ],
-      [ "getHostContext", "classSteinberg_1_1Vst_1_1ComponentBase.html#ae8391f8417d768adbf055876641276cb", null ],
-      [ "getPeer", "classSteinberg_1_1Vst_1_1ComponentBase.html#af5db5c33db4c9fa57a18b66fb714830c", null ],
-      [ "allocateMessage", "classSteinberg_1_1Vst_1_1ComponentBase.html#aae7bbbf07353224bb0ba77a091b87d33", null ],
-      [ "sendMessage", "classSteinberg_1_1Vst_1_1ComponentBase.html#aa3484053dd9d99fb072465f65ed3a58e", null ],
-      [ "sendTextMessage", "classSteinberg_1_1Vst_1_1ComponentBase.html#a92accc56f3a2d30116b52b3f5948101b", null ],
-      [ "sendMessageID", "classSteinberg_1_1Vst_1_1ComponentBase.html#ab599093d44aa82deac5e46dba5cb8d18", null ],
+      [ "getHostContext", "classSteinberg_1_1Vst_1_1ComponentBase.html#a32faa2a2ce973ebad2c42334decad779", null ],
+      [ "getPeer", "classSteinberg_1_1Vst_1_1ComponentBase.html#ae38ec4832624d4d7d1eca0edaae60476", null ],
+      [ "allocateMessage", "classSteinberg_1_1Vst_1_1ComponentBase.html#ad73cdb71520acbddc432f05afc78f319", null ],
+      [ "sendMessage", "classSteinberg_1_1Vst_1_1ComponentBase.html#a92e46ebbe4a0bd08d08d5cdee2b6c3f2", null ],
+      [ "sendTextMessage", "classSteinberg_1_1Vst_1_1ComponentBase.html#a2e5cfce489ef7d80b91d30c793d0d796", null ],
+      [ "sendMessageID", "classSteinberg_1_1Vst_1_1ComponentBase.html#a5ce1c0c86bd721be406c4a5d8823c200", null ],
       [ "receiveText", "classSteinberg_1_1Vst_1_1ComponentBase.html#a6e27175ee5edbf22022daefbf19aceeb", null ],
       [ "initialize", "classSteinberg_1_1Vst_1_1ComponentBase.html#a4dae123b5697706651d9ff20c9614f63", null ],
       [ "terminate", "classSteinberg_1_1Vst_1_1ComponentBase.html#a272e5d4c8e24f012573f9f5b11f7f569", null ],
@@ -109,7 +109,7 @@ var group__vstClasses =
       [ "getParamNormalized", "classSteinberg_1_1Vst_1_1EditController.html#a6df16b51840a296f8aaaa58a5b4f386c", null ],
       [ "setParamNormalized", "classSteinberg_1_1Vst_1_1EditController.html#aeb78d794ce0bc5812c526a1cc2083d5d", null ],
       [ "setComponentHandler", "classSteinberg_1_1Vst_1_1EditController.html#a375821f541e8b3338d3e2dbfae7433d8", null ],
-      [ "createView", "classSteinberg_1_1Vst_1_1EditController.html#a9ed9952fc33a6e0cac96a8f46de5d86c", null ],
+      [ "createView", "classSteinberg_1_1Vst_1_1EditController.html#adb062d482f63c637efc04c88dfc4b2a3", null ],
       [ "setKnobMode", "classSteinberg_1_1Vst_1_1EditController.html#a9c53db76959c3f687ebf0a9e039b5523", null ],
       [ "openHelp", "classSteinberg_1_1Vst_1_1EditController.html#a990e31f5d0bcc88d2c3a8e8c370a23ca", null ],
       [ "openAboutBox", "classSteinberg_1_1Vst_1_1EditController.html#aff61c36b9f383b24e53096d1ff4ca451", null ],
@@ -123,18 +123,18 @@ var group__vstClasses =
       [ "editorDestroyed", "classSteinberg_1_1Vst_1_1EditController.html#a0d848355600e651408719e8a288426ef", null ],
       [ "editorAttached", "classSteinberg_1_1Vst_1_1EditController.html#a6b866568fd49fdf6f8b310fd468389ee", null ],
       [ "editorRemoved", "classSteinberg_1_1Vst_1_1EditController.html#a30a5f278c9ad42c540a11823241e59e3", null ],
-      [ "getParameterObject", "classSteinberg_1_1Vst_1_1EditController.html#a8bffbfa7db25344bb01ea135d6a92275", null ],
+      [ "getParameterObject", "classSteinberg_1_1Vst_1_1EditController.html#a6f8fb06dcfa0afac39f290714b3c7b62", null ],
       [ "getParameterInfoByTag", "classSteinberg_1_1Vst_1_1EditController.html#aeb65e428ca527d391f1250247611ec54", null ],
       [ "setDirty", "classSteinberg_1_1Vst_1_1EditController.html#a460c259c620b7dbe5ee1f0e7bef6cd23", null ],
       [ "requestOpenEditor", "classSteinberg_1_1Vst_1_1EditController.html#a96eb2b9463edb639bd3cd9a61dd95626", null ],
-      [ "getComponentHandler", "classSteinberg_1_1Vst_1_1EditController.html#abc58c5d47a3e00815e1b3c043daeefa3", null ],
+      [ "getComponentHandler", "classSteinberg_1_1Vst_1_1EditController.html#a25717548e5f255905f319483b2109100", null ],
       [ "componentHandler2", "classSteinberg_1_1Vst_1_1EditController.html#a9f6f0649ff7efe6061d32acef2e397e2", null ],
       [ "parameters", "classSteinberg_1_1Vst_1_1EditController.html#ac4e5827457c66ced54509c5179a5bb4c", null ]
     ] ],
     [ "EditorView", "classSteinberg_1_1Vst_1_1EditorView.html", [
       [ "EditorView", "classSteinberg_1_1Vst_1_1EditorView.html#a04fe421361ccb6e2127b486a198e7adf", null ],
       [ "~EditorView", "classSteinberg_1_1Vst_1_1EditorView.html#a0604e41b561a0dee460052ae5f350b0d", null ],
-      [ "getController", "classSteinberg_1_1Vst_1_1EditorView.html#a061dda7bad880061767d3b1b1294026e", null ],
+      [ "getController", "classSteinberg_1_1Vst_1_1EditorView.html#addc6877278368777173745f04a0abd45", null ],
       [ "attachedToParent", "classSteinberg_1_1Vst_1_1EditorView.html#a6d3d17488dd894c98e3eeaf4836739b3", null ],
       [ "removedFromParent", "classSteinberg_1_1Vst_1_1EditorView.html#ac56bd2ced2b9679faf3bd28125c85b8b", null ],
       [ "controller", "classSteinberg_1_1Vst_1_1EditorView.html#adf2e2c35f1cc675644d44a5318162ffd", null ]
@@ -142,12 +142,12 @@ var group__vstClasses =
     [ "Unit", "classSteinberg_1_1Vst_1_1Unit.html", [
       [ "Unit", "classSteinberg_1_1Vst_1_1Unit.html#a50125d90c2d04510fdb684ba3fac21dd", null ],
       [ "Unit", "classSteinberg_1_1Vst_1_1Unit.html#a74283874e8ea9c7f41dfdcf9ff43ee30", null ],
-      [ "getInfo", "classSteinberg_1_1Vst_1_1Unit.html#a7f306255161349b24f8c32b1775d8fb0", null ],
-      [ "getID", "classSteinberg_1_1Vst_1_1Unit.html#a1536c30a1d382bd559f6cd4f82f928d7", null ],
+      [ "getInfo", "classSteinberg_1_1Vst_1_1Unit.html#a342d4dd44e1a3087400d596282f504b8", null ],
+      [ "getID", "classSteinberg_1_1Vst_1_1Unit.html#aed9c0251fed984387e905466ee487f01", null ],
       [ "setID", "classSteinberg_1_1Vst_1_1Unit.html#a6da8a9198e1aec0ef3199fc793dea2e1", null ],
-      [ "getName", "classSteinberg_1_1Vst_1_1Unit.html#a83c7c1d26e0f0086b1046e064671741d", null ],
+      [ "getName", "classSteinberg_1_1Vst_1_1Unit.html#a37af22895f84aa8447f84b156a8d2bd5", null ],
       [ "setName", "classSteinberg_1_1Vst_1_1Unit.html#ab1eec84040a94f6349c8269174fa8364", null ],
-      [ "getProgramListID", "classSteinberg_1_1Vst_1_1Unit.html#a296c1726513b59a6c28f501a6559b4d7", null ],
+      [ "getProgramListID", "classSteinberg_1_1Vst_1_1Unit.html#aa171b2561c9d718688511554030eecc3", null ],
       [ "setProgramListID", "classSteinberg_1_1Vst_1_1Unit.html#a8e445c6372ee7a6bbb5407dd998e9ed8", null ],
       [ "info", "classSteinberg_1_1Vst_1_1Unit.html#ada34a9c3bca142b51fbefe76a6002a23", null ]
     ] ],
@@ -156,10 +156,10 @@ var group__vstClasses =
       [ "ProgramInfoVector", "classSteinberg_1_1Vst_1_1ProgramList.html#a43790e03c786a44ac4501bf277e660e6", null ],
       [ "ProgramList", "classSteinberg_1_1Vst_1_1ProgramList.html#a064d4941eb4a37a951ba11db619139a1", null ],
       [ "ProgramList", "classSteinberg_1_1Vst_1_1ProgramList.html#af096804513689f8f3e210b22c69df785", null ],
-      [ "getInfo", "classSteinberg_1_1Vst_1_1ProgramList.html#a0f55ca555669766ed9fdda63093dd162", null ],
-      [ "getID", "classSteinberg_1_1Vst_1_1ProgramList.html#add18e0aad4ce223d6bb1a551d870a5cd", null ],
-      [ "getName", "classSteinberg_1_1Vst_1_1ProgramList.html#a83c7c1d26e0f0086b1046e064671741d", null ],
-      [ "getCount", "classSteinberg_1_1Vst_1_1ProgramList.html#a58d84cb2f5e9d88369c4b8b485d8f7b6", null ],
+      [ "getInfo", "classSteinberg_1_1Vst_1_1ProgramList.html#a462eb2c997ccd52fbec46ab47325b987", null ],
+      [ "getID", "classSteinberg_1_1Vst_1_1ProgramList.html#aeb01bbce36d25fb31c83d5137f8bbb1b", null ],
+      [ "getName", "classSteinberg_1_1Vst_1_1ProgramList.html#a37af22895f84aa8447f84b156a8d2bd5", null ],
+      [ "getCount", "classSteinberg_1_1Vst_1_1ProgramList.html#a98fde1d644ee94d8a1b0281ecc60163c", null ],
       [ "getProgramName", "classSteinberg_1_1Vst_1_1ProgramList.html#a06b4414f55178bc9cb508df9987aaebb", null ],
       [ "setProgramName", "classSteinberg_1_1Vst_1_1ProgramList.html#a20f9c9e10a481827f36fe6160c91f516", null ],
       [ "getProgramInfo", "classSteinberg_1_1Vst_1_1ProgramList.html#a3b5812b08d35fde419d28fda98397d46", null ],
@@ -186,13 +186,13 @@ var group__vstClasses =
     ] ],
     [ "EditControllerEx1", "classSteinberg_1_1Vst_1_1EditControllerEx1.html", [
       [ "ProgramIndexMap", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a1926d11ac5eb67ab443e956596b136bf", null ],
-      [ "UnitVector", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a17bdb5b5f4819158a18138198cb4dddc", null ],
+      [ "UnitVector", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a687ee1e9d187cd0224fbcc4750addb5c", null ],
       [ "EditControllerEx1", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a811774900d44bda403000f2b423bcbe5", null ],
       [ "~EditControllerEx1", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#abeab0355fc2fa4cf2c7e66cb30db79e7", null ],
       [ "terminate", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a272e5d4c8e24f012573f9f5b11f7f569", null ],
       [ "addUnit", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a8fbc2c8dab1b94795bcaf35473fabdfc", null ],
       [ "addProgramList", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a97c6d1b843066330ec399d1a66fe64d1", null ],
-      [ "getProgramList", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a2c71a51dd66bd96a8870e0e71fc20a89", null ],
+      [ "getProgramList", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a98a0aa0fc50c7cd4a49714677123d573", null ],
       [ "notifyProgramListChange", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a7e5f835a7ec04e2382ef5be787139694", null ],
       [ "getUnitCount", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a3ae1f7465f6641b01f76a098d0467b72", null ],
       [ "getUnitInfo", "classSteinberg_1_1Vst_1_1EditControllerEx1.html#a8b9ae87a7ee8a5616500ad864daac193", null ],
@@ -240,12 +240,12 @@ var group__vstClasses =
       [ "NoteExpressionType", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#aea5044c520938cf8ef392271a40f0366", null ],
       [ "NoteExpressionType", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a1b410fc486d740126d474a33440ab519", null ],
       [ "NoteExpressionType", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a92ece185a74a032e1097039e9f55756f", null ],
-      [ "getInfo", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a894387ae14412c6b95e0efc020217ce5", null ],
+      [ "getInfo", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#ae4be1144ae256a9b50fce7f4bfe8840d", null ],
       [ "getStringByValue", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a54a175d6c29995441f458ad2bbea9931", null ],
       [ "getValueByString", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a8a56c1da16268a00189b69e670190222", null ],
-      [ "getPrecision", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a2b186fa231408e88f93f58e8144b5d61", null ],
+      [ "getPrecision", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a90faa67aec02cdf7f88bac5fa8acc0e2", null ],
       [ "setPrecision", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#abf80191a6dcaba94638e0bc7efd029c5", null ],
-      [ "getPhysicalUIType", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a2f98266f39d184941603d260bb7ea49d", null ],
+      [ "getPhysicalUIType", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a071ee3f5238fa6d1d47be964c3232b6e", null ],
       [ "setPhysicalUITypeID", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a8d529444c76a7df6ef7323538a65bc60", null ],
       [ "associatedParameter", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#a399a58c623c23e7abc78f9c6a443d16f", null ],
       [ "precision", "classSteinberg_1_1Vst_1_1NoteExpressionType.html#ae19c2c90f8dec6b6c96ff91b584c2b11", null ],
@@ -253,9 +253,9 @@ var group__vstClasses =
     ] ],
     [ "RangeNoteExpressionType", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html", [
       [ "RangeNoteExpressionType", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#a71ad654389a50ee640478ebb0308ccec", null ],
-      [ "getMin", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#a0983c983ec34756d0e48caa0e09d1b9a", null ],
+      [ "getMin", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#a194be51a0d5d72a88a5c3c2b06c68b5a", null ],
       [ "setMin", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#acbbcff1787274988f70716800f19aafb", null ],
-      [ "getMax", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#a2da8f7d907b89deb5617e3aff7e2f38b", null ],
+      [ "getMax", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#a5776d6b0cfb3bc2d1208194fc17b0357", null ],
       [ "setMax", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#a0eb05e3600bb5edc5f0771f6d94e037e", null ],
       [ "getStringByValue", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#a5793c3e551b4cf0ee5b4c29adb61d03b", null ],
       [ "getValueByString", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html#afccc02c9baeb9a880bd44a480d4ce66a", null ],
@@ -272,7 +272,7 @@ var group__vstClasses =
       [ "getNoteExpressionStringByValue", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#a45a86b6c379a97091c3abe9dc128a431", null ],
       [ "getNoteExpressionValueByString", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#a9d8f0b17d2dfc86e6eb8c2282c3f54e2", null ],
       [ "getMappedNoteExpression", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#ae6d96845d749ee274d85820210b2de82", null ],
-      [ "find", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#ac93bea44934ede96c71738cd52fa29ba", null ],
+      [ "find", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#ad98f877a950598b7c7585bc888091374", null ],
       [ "noteExps", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#a8aa4091983fc7ad18dda56edea18d9e9", null ]
     ] ],
     [ "Parameter", "classSteinberg_1_1Vst_1_1Parameter.html", [
@@ -280,17 +280,17 @@ var group__vstClasses =
       [ "Parameter", "classSteinberg_1_1Vst_1_1Parameter.html#a388e837bf6198abab80b877ca32b5e26", null ],
       [ "Parameter", "classSteinberg_1_1Vst_1_1Parameter.html#a75669d5409d1f3c14d0786633330046e", null ],
       [ "~Parameter", "classSteinberg_1_1Vst_1_1Parameter.html#a7861fe34a626dcd417dc1ebe50be25b6", null ],
-      [ "getInfo", "classSteinberg_1_1Vst_1_1Parameter.html#a71d6e49dfb5ed250f9df6593c811ee54", null ],
-      [ "getInfo", "classSteinberg_1_1Vst_1_1Parameter.html#a2bc73892288f11d7c221582273a1bd05", null ],
+      [ "getInfo", "classSteinberg_1_1Vst_1_1Parameter.html#a3cc5198f7343e3c1283b0cab3e444ce3", null ],
+      [ "getInfo", "classSteinberg_1_1Vst_1_1Parameter.html#a2deab82548ad4a1822de20c683e15178", null ],
       [ "setUnitID", "classSteinberg_1_1Vst_1_1Parameter.html#adbfcb4b21973f6480502111f899ff8da", null ],
       [ "getUnitID", "classSteinberg_1_1Vst_1_1Parameter.html#a21aef1eeb23ef6e414cba252690795a5", null ],
-      [ "getNormalized", "classSteinberg_1_1Vst_1_1Parameter.html#a900f4c886d0ec3012445a0eda9bf89fb", null ],
+      [ "getNormalized", "classSteinberg_1_1Vst_1_1Parameter.html#aab775bfb1ab9c47fb57f9a1aa9b01393", null ],
       [ "setNormalized", "classSteinberg_1_1Vst_1_1Parameter.html#a31d234fd0b37a33579e134c6bc769e9d", null ],
-      [ "toString", "classSteinberg_1_1Vst_1_1Parameter.html#abf2d66439b66c3c696d3c65ce53ca324", null ],
-      [ "fromString", "classSteinberg_1_1Vst_1_1Parameter.html#aa0ff61e185c085fe7d7a34aed67fca38", null ],
-      [ "toPlain", "classSteinberg_1_1Vst_1_1Parameter.html#a4490b3abfe579ec2e70de79870c7dfd6", null ],
-      [ "toNormalized", "classSteinberg_1_1Vst_1_1Parameter.html#a8a0c6d8c8afd49db1e9a6c0746002d35", null ],
-      [ "getPrecision", "classSteinberg_1_1Vst_1_1Parameter.html#a3b53ec71314befdb8764d3061bbd55d6", null ],
+      [ "toString", "classSteinberg_1_1Vst_1_1Parameter.html#a9ab85d42c0e04aa353c088ba1a719096", null ],
+      [ "fromString", "classSteinberg_1_1Vst_1_1Parameter.html#a389243df342667a564a24584382798c2", null ],
+      [ "toPlain", "classSteinberg_1_1Vst_1_1Parameter.html#a89049304e95fdeefd15e841479d85fb7", null ],
+      [ "toNormalized", "classSteinberg_1_1Vst_1_1Parameter.html#a3658cc024bfd4c28bef95b8508ce398d", null ],
+      [ "getPrecision", "classSteinberg_1_1Vst_1_1Parameter.html#a7768408235e83f9877e1c9e77224403e", null ],
       [ "setPrecision", "classSteinberg_1_1Vst_1_1Parameter.html#af3783cde85022795e4e6cfc78e627262", null ],
       [ "valueNormalized", "classSteinberg_1_1Vst_1_1Parameter.html#a0ccc625642bc5f50bad1ecf1de846017", null ],
       [ "precision", "classSteinberg_1_1Vst_1_1Parameter.html#ae19c2c90f8dec6b6c96ff91b584c2b11", null ]
@@ -298,9 +298,9 @@ var group__vstClasses =
     [ "RangeParameter", "classSteinberg_1_1Vst_1_1RangeParameter.html", [
       [ "RangeParameter", "classSteinberg_1_1Vst_1_1RangeParameter.html#a5a97834c5e607e30474978393cd01d35", null ],
       [ "RangeParameter", "classSteinberg_1_1Vst_1_1RangeParameter.html#a9f3ded62c97296929ef2933cd432fdaf", null ],
-      [ "getMin", "classSteinberg_1_1Vst_1_1RangeParameter.html#a0983c983ec34756d0e48caa0e09d1b9a", null ],
+      [ "getMin", "classSteinberg_1_1Vst_1_1RangeParameter.html#a194be51a0d5d72a88a5c3c2b06c68b5a", null ],
       [ "setMin", "classSteinberg_1_1Vst_1_1RangeParameter.html#acbbcff1787274988f70716800f19aafb", null ],
-      [ "getMax", "classSteinberg_1_1Vst_1_1RangeParameter.html#a2da8f7d907b89deb5617e3aff7e2f38b", null ],
+      [ "getMax", "classSteinberg_1_1Vst_1_1RangeParameter.html#a5776d6b0cfb3bc2d1208194fc17b0357", null ],
       [ "setMax", "classSteinberg_1_1Vst_1_1RangeParameter.html#a0eb05e3600bb5edc5f0771f6d94e037e", null ],
       [ "toString", "classSteinberg_1_1Vst_1_1RangeParameter.html#ab8cb2d05d8f8af76a610e783faecb324", null ],
       [ "fromString", "classSteinberg_1_1Vst_1_1RangeParameter.html#af7aab53314d6d62ad5b017ba85ab50b5", null ],
@@ -322,7 +322,7 @@ var group__vstClasses =
       [ "strings", "classSteinberg_1_1Vst_1_1StringListParameter.html#a5a9dee2a0836631d70d59cde796132a0", null ]
     ] ],
     [ "ParameterContainer", "classSteinberg_1_1Vst_1_1ParameterContainer.html", [
-      [ "ParameterPtrVector", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a6c53528dbca2a65e9fd7e368c4e17b27", null ],
+      [ "ParameterPtrVector", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a4741f281ae770bca7eef575bc328452c", null ],
       [ "IndexMap", "classSteinberg_1_1Vst_1_1ParameterContainer.html#acc6c61f4d3ab4f9f73bcb86f5dde86ab", null ],
       [ "ParameterContainer", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a754120b3ba17224055c6de192ec053a2", null ],
       [ "~ParameterContainer", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a023243865c40e3198f716d09ad53c585", null ],
@@ -330,10 +330,10 @@ var group__vstClasses =
       [ "addParameter", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a85fdb751a90bc332b258174367c3ae21", null ],
       [ "addParameter", "classSteinberg_1_1Vst_1_1ParameterContainer.html#ab1ea7afd1ecc429f8324b751082e4b0f", null ],
       [ "addParameter", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a6214dce887302e2cdc39fe332ce899a5", null ],
-      [ "getParameterCount", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a0321ac02fa41dfbea9fd1339c7946c8b", null ],
-      [ "getParameterByIndex", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a77e5e83ef1f52d3e0e25a7d94342f286", null ],
+      [ "getParameterCount", "classSteinberg_1_1Vst_1_1ParameterContainer.html#af13945f51c49cf1a2ab03d31c11a7349", null ],
+      [ "getParameterByIndex", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a39896fc5c802a18f9bb71c5303e841ae", null ],
       [ "removeAll", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a9b0a5a3ad9972ab0e8eb0b54873aac6b", null ],
-      [ "getParameter", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a3e0742c4b4e499d7a19e1d1aab945d40", null ],
+      [ "getParameter", "classSteinberg_1_1Vst_1_1ParameterContainer.html#abbb77f46936fad5532986e0fb7dd6613", null ],
       [ "removeParameter", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a17ccf658ed2936c9d740dd1c5fada5dc", null ],
       [ "params", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a09ad76517b311128144d1a5d0dbfee99", null ],
       [ "id2index", "classSteinberg_1_1Vst_1_1ParameterContainer.html#a675e5686e00452815dca960c7730fe68", null ]
@@ -344,17 +344,16 @@ var group__vstClasses =
         [ "offset", "structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html#a3695b4badbf1fecec9ceaad8ce6bdc50", null ],
         [ "size", "structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html#ab1758d5ff5bb8a9770c8c1e1b3b5b5f9", null ]
       ] ],
-      [ "kMaxEntries", "classSteinberg_1_1Vst_1_1PresetFile.html#a06fc87d81c62e9abb8790b6e5713c55ba7c523f5cdb8166ac95e994b9e6359476", null ],
       [ "PresetFile", "classSteinberg_1_1Vst_1_1PresetFile.html#a9db1b48345e92320b0dffc446d5e3483", null ],
       [ "~PresetFile", "classSteinberg_1_1Vst_1_1PresetFile.html#aceb1e59d2e7000e35be20567f756081e", null ],
-      [ "getStream", "classSteinberg_1_1Vst_1_1PresetFile.html#a4b1729996cbeb7ea2092042314499c42", null ],
-      [ "getClassID", "classSteinberg_1_1Vst_1_1PresetFile.html#a0518e18874378e575de0d7a7a56f9023", null ],
+      [ "getStream", "classSteinberg_1_1Vst_1_1PresetFile.html#a4db29b8ddd64d91776beb8a17d1fbbd0", null ],
+      [ "getClassID", "classSteinberg_1_1Vst_1_1PresetFile.html#a7f5d83cc2c5049207d5e86e3495b78c0", null ],
       [ "setClassID", "classSteinberg_1_1Vst_1_1PresetFile.html#a5c0e62acbe9d309d79aa7f65e4e66a1f", null ],
-      [ "getEntry", "classSteinberg_1_1Vst_1_1PresetFile.html#a1ca86f6e096f1c15ce2ae78f69f9d381", null ],
-      [ "getLastEntry", "classSteinberg_1_1Vst_1_1PresetFile.html#a43b40fc146bb9be74e5d7792b4892ba0", null ],
-      [ "getEntryCount", "classSteinberg_1_1Vst_1_1PresetFile.html#a656e047d537eb8629db04827fbc17588", null ],
-      [ "at", "classSteinberg_1_1Vst_1_1PresetFile.html#a2508c50409f050748cc7920d2fcceb0b", null ],
-      [ "contains", "classSteinberg_1_1Vst_1_1PresetFile.html#a0ec5e8e4ff96a6527750a9646d398bb3", null ],
+      [ "getEntry", "classSteinberg_1_1Vst_1_1PresetFile.html#a6b62d2219c74585f8ecab339881f9eba", null ],
+      [ "getLastEntry", "classSteinberg_1_1Vst_1_1PresetFile.html#aeb9c5727279628f7a0f3067ac700c02f", null ],
+      [ "getEntryCount", "classSteinberg_1_1Vst_1_1PresetFile.html#a92008de76954ce7f80216da886c7fd72", null ],
+      [ "at", "classSteinberg_1_1Vst_1_1PresetFile.html#a4799336c451346dec2989af13c6f5649", null ],
+      [ "contains", "classSteinberg_1_1Vst_1_1PresetFile.html#a47df1b291bef4cbc1b23f80098e1a7af", null ],
       [ "readChunkList", "classSteinberg_1_1Vst_1_1PresetFile.html#a3b0d2ad5888c742d113cca6302e4568d", null ],
       [ "writeHeader", "classSteinberg_1_1Vst_1_1PresetFile.html#a71260916b31668ed8727d8e382b27c80", null ],
       [ "writeChunkList", "classSteinberg_1_1Vst_1_1PresetFile.html#a3e7d860cd2df89230c8d0664c8858e2d", null ],
@@ -394,12 +393,6 @@ var group__vstClasses =
       [ "entryCount", "classSteinberg_1_1Vst_1_1PresetFile.html#a4f71f86dadbbb1cf5a477c64587ca491", null ]
     ] ],
     [ "XmlRepresentationHelper", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html", [
-      [ "kInRepresentation", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#adf764cbdea00d65edcd07bb9953ad2b7af0cf5cce87ba2cc97522590350412484", null ],
-      [ "kInPage", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#adf764cbdea00d65edcd07bb9953ad2b7a647b9baecf2e680ebc63b346d0e4e0d6", null ],
-      [ "kInCell", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#adf764cbdea00d65edcd07bb9953ad2b7a84809f54cc1b556f8ace8b59f6da6317", null ],
-      [ "kInLayer", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#adf764cbdea00d65edcd07bb9953ad2b7a3693c6360209705c905d60a7d8d88138", null ],
-      [ "kInTitleDisplay", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#adf764cbdea00d65edcd07bb9953ad2b7a1a92cc5b6e2a8795a3cd433a0dff7a19", null ],
-      [ "kInName", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#adf764cbdea00d65edcd07bb9953ad2b7a90dd27033d3d683e310ff11536946f04", null ],
       [ "XmlRepresentationHelper", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#a86e23718aef1f6a0b3cab474967ac0b9", null ],
       [ "~XmlRepresentationHelper", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#a9de53b27f3ed60398d9e5ba7fe2ef14e", null ],
       [ "startPage", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#a86ce45d066c2044df986e52083c69203", null ],
@@ -434,8 +427,8 @@ var group__vstClasses =
       [ "getRoutingInfo", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a7af5768bbbab94f5a227313fff6ef74e", null ],
       [ "activateBus", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#af98a434f211539013a174bbe191156e3", null ],
       [ "setActive", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a82771278a563c17a20eaf97f8fb14311", null ],
-      [ "setEditorState", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a5c45cf61d3d8331302cdc6cad9ba2b3d", null ],
-      [ "getEditorState", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#ab5393bfe75dac26ada3d2f33b5f372cf", null ],
+      [ "setState", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a244b615a88bc3b9ef68b30ba63fcb662", null ],
+      [ "getState", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a65536f6c30008323e115c173d1677b91", null ],
       [ "addAudioInput", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#acf5189a9e37c263015c22a7f81b750c8", null ],
       [ "addAudioOutput", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aee9f447229f5bf7247c00d39f4bb748d", null ],
       [ "addEventInput", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a98a16757564b1a077d82e2b2decc2ad8", null ],
