@@ -2,7 +2,7 @@ var module__linux_8cpp =
 [
     [ "USE_EXPERIMENTAL_FS", "module__linux_8cpp.html#a7f7123ffe9352ede10ecc711ae8901d3", null ],
     [ "ModuleEntryFunc", "module__linux_8cpp.html#a9b715f5fd5674dcf99d4b3b286f9c993", null ],
-    [ "ModuleExitFunc", "module__linux_8cpp.html#a71d82882268b976c5260a89577b9d2f9", null ],
+    [ "ModuleExitFunc", "module__linux_8cpp.html#a6bb67fd6e30b095f26ee8859d12de8ef", null ],
     [ "Path", "module__linux_8cpp.html#ada742d09a758c7053b346ceab75bfa58", null ],
-    [ "nullptr", "module__linux_8cpp.html#a19968797a6fea0ed90fe831e4bf4f5bd", null ]
+    [ "mModule", "module__linux_8cpp.html#a2f8d15415d186671c101186f3cb67860", null ]
 ];
\ No newline at end of file
