@@ -4,8 +4,8 @@ var module__win32_8cpp =
     [ "_SILENCE_EXPERIMENTAL_FILESYSTEM_DEPRECATION_WARNING", "module__win32_8cpp.html#aab6af62131aad81d17d3b4afd9db334f", null ],
     [ "USE_OLE", "module__win32_8cpp.html#af1ce76814dd30ab1a712aaee424a9525", null ],
     [ "LOG_ENABLE", "module__win32_8cpp.html#aba0050d0d9182386e51d25ec355f4f8d", null ],
-    [ "InitModuleFunc", "module__win32_8cpp.html#ab960ef10cf6ba5f66c273a348d70cef7", null ],
-    [ "ExitModuleFunc", "module__win32_8cpp.html#a56b0f237e07f0782cc40b2e9f12d4a92", null ],
+    [ "InitModuleFunc", "module__win32_8cpp.html#a8a1e393b01e903bee13c2bdba15dcea5", null ],
+    [ "ExitModuleFunc", "module__win32_8cpp.html#aec121fc4a56e70a587fd2cb5f4d9883e", null ],
     [ "kIPPathNameMax", "module__win32_8cpp.html#adc18f3cbe8d2b92a8350abbed9157fab", null ],
-    [ "nullptr", "module__win32_8cpp.html#a41ef2c2b409468fd271243d107c85e12", null ]
+    [ "mModule", "module__win32_8cpp.html#a872231d16d10835d836c77daa67fee18", null ]
 ];
\ No newline at end of file
