@@ -1,12 +1,14 @@
 var stringconvert_8h =
 [
     [ "convert", "stringconvert_8h.html#a7b24e433664bafa3dd3f9357ec3f6c4d", null ],
+    [ "convert", "stringconvert_8h.html#abff8a368026b5ff872b48945fcf3113f", null ],
+    [ "convert", "stringconvert_8h.html#ab20bb6b50e97de71fea1897b45dca317", null ],
     [ "convert", "stringconvert_8h.html#ab16efb35664dd3b3202ebc37571ae369", null ],
     [ "convert", "stringconvert_8h.html#a516c6fb6f3feea42db8958f97e146129", null ],
     [ "convert", "stringconvert_8h.html#a931b7bcc1c22509766093e32f28d2e23", null ],
-    [ "convert", "stringconvert_8h.html#ad0e56044e282dcac7890cbce544aa83f", null ],
-    [ "convert", "stringconvert_8h.html#abff8a368026b5ff872b48945fcf3113f", null ],
-    [ "convert", "stringconvert_8h.html#ab20bb6b50e97de71fea1897b45dca317", null ],
-    [ "toTChar", "stringconvert_8h.html#a207e23e9cafce1b77acf9da2f72f2fc9", null ],
-    [ "toString", "stringconvert_8h.html#a4057efa382a8c98391f469c2a6f98ac5", null ]
+    [ "toTChar", "stringconvert_8h.html#adddd2ecf30f024c6f4e679bf1f517086", null ],
+    [ "toString", "stringconvert_8h.html#a26aac7af543c28a1d31d2e2844eaa669", null ],
+    [ "SMTG_DEPRECATED_MSG", "stringconvert_8h.html#a203be2421bab29e8a54581095d863309", null ],
+    [ "SMTG_DEPRECATED_MSG", "stringconvert_8h.html#af1e63d1e65d82ff5f484e4b5ec7c2860", null ],
+    [ "SMTG_DEPRECATED_MSG", "stringconvert_8h.html#a44d57efe7fbba4ccc78ca7b189b134ff", null ]
 ];
\ No newline at end of file
